@@ -1,7 +1,7 @@
 package Template::Caribou;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: class-based HTML-centric templating system
-$Template::Caribou::VERSION = '1.0.0';
+$Template::Caribou::VERSION = '1.1.0';
 use Carp;
 
 use Moose::Exporter;
@@ -11,12 +11,23 @@ use Template::Caribou::Tags qw/ attr /;
 
 Moose::Exporter->setup_import_methods(
     with_meta => [ 'template' ],
-    as_is     => [ 'attr' ],
+    as_is     => [ 'attr', 'show' ],
     also      => [ 'Template::Caribou::Role' ],
 );
 
 use Moose::Util qw/ apply_all_roles /;
 
+use 5.10.0;
+
+sub show {
+    state $shown_warning = 0;
+
+    carp 'show() is deprecated, use $bou->my_template instead'
+        unless $shown_warning++;
+
+    $Template::Caribou::TEMPLATE->render(@_);
+}
+
 sub init_meta {
     my $class = shift;
     my %args = @_;
@@ -47,7 +58,7 @@ Template::Caribou - class-based HTML-centric templating system
 
 =head1 VERSION
 
-version 1.0.0
+version 1.1.0
 
 =head1 SYNOPSIS
 
