@@ -1,7 +1,7 @@
 package Template::Caribou::Tags;
 our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: generates tags functions for Caribou templates
-$Template::Caribou::Tags::VERSION = '1.0.0';
+$Template::Caribou::Tags::VERSION = '1.1.0';
 
 use strict;
 use warnings;
@@ -10,24 +10,36 @@ use Carp;
 
 use Template::Caribou::Role;
 
+use List::AllUtils qw/ pairmap pairgrep /;
+
 use parent 'Exporter::Tiny';
-use experimental 'signatures';
+use experimental 'signatures', 'postderef';
 
 
 our @EXPORT_OK = qw/ render_tag mytag attr /;
 
 
 sub attr(@){
-    return $Template::Caribou::Attr{$_[0]} if @_ == 1;
+    return $_{$_[0]} if @_ == 1;
 
     croak "number of attributes must be even" if @_ % 2;
 
+    no warnings 'uninitialized';
     while( my ( $k, $v ) = splice @_, 0, 2 ) {
         if ( $k =~ s/^\+// ) {
-            $Template::Caribou::Attr{$k} .= ' '. $v;
+            $_{$k} = { map { $_ => 1 } split ' ', $_{$k} }
+                unless ref $_{$k};
+
+            $_{$k}{$v} = 1;
+        }
+        elsif ( $k =~ s/^-// ) {
+            $_{$k} = { map { $_ => 1 } split ' ', $_{$k} }
+                unless ref $_{$k};
+
+            delete $_{$k}{$v};
         }
         else {
-            $Template::Caribou::Attr{$k} = $v;
+            $_{$k} = $v;
         }
     }
 
@@ -44,7 +56,19 @@ sub _generate_mytag {
     my $tagname = $arg->{tag} || 'div';
 
     my $groom = sub {
-        $_{class} ||= $arg->{class} if $arg->{class};
+        
+        no warnings 'uninitialized';
+
+        if( my $defaults = $arg->{classes} || $arg->{class} ) {
+            $_{class} = { map { $_ => 1 } split ' ', $_{class} }
+                unless ref $_{class};
+            if( ref $defaults ) {
+                $_{class}{$_} //= 1 for @$defaults;
+            }
+            else {
+                $_{class}{$_} //=  1 for split ' ', $defaults;
+            }
+        }
 
         $_{$_} ||= $arg->{attr}{$_} for eval { keys %{ $arg->{attr} } };
 
@@ -72,7 +96,7 @@ sub render_tag {
         roles => [ 'Template::Caribou::Role' ] 
     )->new_object;
 
-    local %Template::Caribou::Attr;
+    local %_;
 
     my $inner = do {
         local $Template::Caribou::TAG_INDENT_LEVEL = $Template::Caribou::TAG_INDENT_LEVEL;
@@ -83,22 +107,21 @@ sub render_tag {
         $bou->get_render($sub);
     };
 
-    my %attr = %Template::Caribou::Attr;
-
     if ( $groom ) {
         local $_ = "$inner";  # stringification required in case it's an object
-        local %_ = %attr;
 
         $groom->();
 
-        ($inner,%attr) = ( $_, %_ );
+        $inner = $_;
     }
 
-    my $attrs;
-    for( sort keys %attr ) {
-        # TODO deal with the quotes
-        $attrs .= qq{ $_="$attr{$_}"};
-    }
+    my $attrs = join ' ', '',
+        pairmap { (  qq{$a="$b"} ) x (length $b > 0) }
+        map { 
+            $_ => ref $_{$_} 
+                ? join ' ', sort { $a cmp $b } pairmap { $a } pairgrep { $b } $_{$_}->%* 
+                : $_{$_} 
+        }  grep { defined $_{$_} } sort keys %_;
 
     no warnings qw/ uninitialized /;
 
@@ -132,7 +155,7 @@ Template::Caribou::Tags - generates tags functions for Caribou templates
 
 =head1 VERSION
 
-version 1.0.0
+version 1.1.0
 
 =head1 SYNOPSIS
 
@@ -223,13 +246,18 @@ value of the C<tag> argument. At least one of C<-as> or C<tag> must be given exp
 
 Grooming function for the tag block. See C<render_tag> for more details.
 
-=item class => $classes
+=item classes => \@classes
 
-Default value for the 'class' attribute of the tag.
+Default value for the 'class' attribute of the tag. 
 
     use Template::Caribou::Tags 
                     # <div class="main">...</div>
-        mytag => { -as => 'main_div', class => 'main' };
+        mytag => { -as => 'main_div', classes => [ 'main' ] };
+
+If you want to remove a default class from the tag,
+set its value to C<0> in C<%_>. E.g.,
+
+    main_div { $_{class}{main} = 0; ... };
 
 =item attr => \%attributes
 
@@ -243,6 +271,8 @@ Default set of attributes for the tag.
 
 =function attr( $name => $value )
 
+I recommend you use C<%_> directly instead.
+
 Accesses the attributes of a tag within its block.
 
 If provided an even number of parameters, sets the attributes to those values.
@@ -267,13 +297,15 @@ Many calls to C<attr> can be done within the same block.
 
     # <div class="foo" style="text-align: center">hi there</div>
 
-To add to an attribute instead of replacing its value, prefix the attribute name
-with a plus sign.
+To add/remove to an attribute instead of replacing its value, prefix the attribute name
+with a plus or minus sign. Doing either will automatically 
+turn the value in C<%_> to a hashref.
 
     div {
-        attr class    => 'foo';
+        attr class    => 'foo baz';
 
         attr '+class' => 'bar';
+        attr '-class' => 'baz';
 
         "hi there";
     };
